import { Component, Input, ElementRef, Renderer } from '@angular/core';
import { ImageLoader } from "../providers/image-loader";
export var ImgLoader = (function () {
    function ImgLoader(element, renderer, imageLoader) {
        this.element = element;
        this.renderer = renderer;
        this.imageLoader = imageLoader;
        this.useImg = false;
        this.width = '100%';
        this.height = '100%';
        /**
         * Whether the image is still loading
         */
        this.isLoading = true;
        this.imgSrc = '';
    }
    ImgLoader.prototype.ngOnInit = function () {
        var _this = this;
        if (this.useImg) {
            this.renderer.createElement(this.element.nativeElement, 'img');
            this.imageContainer = this.element.nativeElement.children[0];
        }
        else {
            this.imageContainer = this.element.nativeElement;
            this.renderer.setElementStyle(this.imageContainer, 'width', this.width);
            this.renderer.setElementStyle(this.imageContainer, 'height', this.height);
            this.renderer.setElementStyle(this.imageContainer, 'display', 'block');
            this.renderer.setElementStyle(this.imageContainer, 'background-size', 'contain');
            this.renderer.setElementStyle(this.imageContainer, 'background-repeat', 'no-repeat');
        }
        // fetch image
        this.imageLoader.getImagePath(this.imageUrl)
            .then(function (imageUrl) {
            console.log('imgUrl is: ', imageUrl);
            _this.isLoading = false;
            if (_this.useImg) {
                _this.imgSrc = imageUrl;
            }
            else {
                _this.renderer.setElementStyle(_this.imageContainer, 'background-image', 'url(\'' + imageUrl + '\')');
            }
        });
    };
    ImgLoader.decorators = [
        { type: Component, args: [{
                    selector: 'img-loader',
                    template: ''
                },] },
    ];
    /** @nocollapse */
    ImgLoader.ctorParameters = [
        { type: ElementRef, },
        { type: Renderer, },
        { type: ImageLoader, },
    ];
    ImgLoader.propDecorators = {
        'imageUrl': [{ type: Input, args: ['src',] },],
        'spinner': [{ type: Input },],
        'useImg': [{ type: Input },],
        'width': [{ type: Input },],
        'height': [{ type: Input },],
    };
    return ImgLoader;
}());
//# sourceMappingURL=img-loader.js.map